MmioCam

Struct MmioCam 

pub struct MmioCam<'a> { /* private fields */ }
ConfigurationAccess implementation for memory-mapped access to a PCI root complex, via either a 16 MiB region for the PCI Configuration Access Mechanism or a 256 MiB region for the PCIe Enhanced Configuration Access Mechanism.

Implementations



impl MmioCam<'_>

pub unsafe fn new(mmio_base: *mut u8, cam: Cam) -> MmioCam<'_>

Wraps the PCI root complex with the given MMIO base address.

Panics if the base address is not aligned to a 4-byte boundary.

Safety

mmio_base must be a valid pointer to an appropriately-mapped MMIO region of at least 16 MiB (if cam == Cam::MmioCam) or 256 MiB (if cam == Cam::Ecam). The pointer must be valid for the lifetime 'a, which implies that no Rust references may be used to access any of the memory region at least during that lifetime.