Struct PciRoot
pub struct PciRoot<C>where
C: ConfigurationAccess,{ /* private fields */ }Expand description
The root complex of a PCI bus.
Implementations
impl<C> PciRoot<C>where
C: ConfigurationAccess,
impl<C> PciRoot<C>where
C: ConfigurationAccess,
pub fn new(configuration_access: C) -> PciRoot<C>
pub fn new(configuration_access: C) -> PciRoot<C>
Creates a new PciRoot to access a PCI root complex through the given configuration access
implementation.
pub fn enumerate_bus(&self, bus: u8) -> BusDeviceIterator<C> ⓘ
pub fn enumerate_bus(&self, bus: u8) -> BusDeviceIterator<C> ⓘ
Enumerates PCI devices on the given bus.
pub fn get_status_command(
&self,
device_function: DeviceFunction,
) -> (Status, Command)
pub fn get_status_command( &self, device_function: DeviceFunction, ) -> (Status, Command)
Reads the status and command registers of the given device function.
pub fn set_command(&mut self, device_function: DeviceFunction, command: Command)
pub fn set_command(&mut self, device_function: DeviceFunction, command: Command)
Sets the command register of the given device function.
pub fn capabilities(
&self,
device_function: DeviceFunction,
) -> CapabilityIterator<'_, C> ⓘ
pub fn capabilities( &self, device_function: DeviceFunction, ) -> CapabilityIterator<'_, C> ⓘ
Gets an iterator over the capabilities of the given device function.
pub fn bars(
&mut self,
device_function: DeviceFunction,
) -> Result<[Option<BarInfo>; 6], PciError>
pub fn bars( &mut self, device_function: DeviceFunction, ) -> Result<[Option<BarInfo>; 6], PciError>
Returns information about all the given device function’s BARs.
pub fn bar_info(
&mut self,
device_function: DeviceFunction,
bar_index: u8,
) -> Result<Option<BarInfo>, PciError>
pub fn bar_info( &mut self, device_function: DeviceFunction, bar_index: u8, ) -> Result<Option<BarInfo>, PciError>
Gets information about the given BAR of the given device function.
pub fn set_bar_32(
&mut self,
device_function: DeviceFunction,
bar_index: u8,
address: u32,
)
pub fn set_bar_32( &mut self, device_function: DeviceFunction, bar_index: u8, address: u32, )
Sets the address of the given 32-bit memory or I/O BAR of the given device function.
pub fn set_bar_64(
&mut self,
device_function: DeviceFunction,
bar_index: u8,
address: u64,
)
pub fn set_bar_64( &mut self, device_function: DeviceFunction, bar_index: u8, address: u64, )
Sets the address of the given 64-bit memory BAR of the given device function.